#!/bin/sh

RIP_CONFIG="/etc/ripd.conf"

. /etc/linuxigd/RouterConfig

WAN_IF="$1"
LAN_IF="$2"

#
# RIP protocol is enabled
#
if [ "$RipEnableWAN" = "1" ] || [ "$RipEnableLAN" = "1" ]; then

   echo "Reading RIP configuration file ......"

   #--------------------     
   # Authentication key
   #--------------------     
   for i in WAN LAN; do
     eval  AuthMethod='$'RipAuthMethod${i}
     if [ "$AuthMethod" != "Disable" ]; then
         eval  AuthKey='$'RipAuthKey${i}
         echo "key chain Auth$i" >> $RIP_CONFIG
         echo "key 1" >> $RIP_CONFIG
         if [ "$AuthKey" != "" ]; then
             echo "key-string $AuthKey" >> $RIP_CONFIG
         else
             echo "key-string none" >> $RIP_CONFIG
	 fi
     fi
   done
   #----------------------------
   # Setting for each interface
   #----------------------------
   for i in WAN LAN; do
      eval IfEnable='$'RipEnable${i}
      if [ "$IfEnable" = "1" ]; then
         eval IF='$'${i}_IF
         echo "interface $IF" >> $RIP_CONFIG
      else
            continue
      fi
      #-------------
      # RIP version
      #-------------
      eval Version='$'RipVersion${i}
      if [ "$Version" = "RIP1" ]; then
           ver="1"
      elif [ "$Version" = "RIP2" ]; then
           ver="2"
      else
           ver="1 2"
      fi
      echo "ip rip send version $ver" >> $RIP_CONFIG
      echo "ip rip receive version $ver" >> $RIP_CONFIG
      #-----------------------
      # Authentication method
      #-----------------------
      eval  AuthMethod='$'RipAuthMethod${i}
      if [ "$AuthMethod" = "Text" ]; then 
           echo "ip rip authentication mode text" >> $RIP_CONFIG
           echo "ip rip authentication key-chain Auth$i" >> $RIP_CONFIG
      elif [ "$AuthMethod" = "MD5" ]; then
           echo "ip rip authentication mode md5" >> $RIP_CONFIG
           echo "ip rip authentication key-chain Auth$i" >> $RIP_CONFIG
      fi
      #--------------
      # Split-horizon
      #--------------
      eval SplitHorizon='$'RipSp${i}Enable
      if [ "$SplitHorizon" = "0" ]; then
           echo "no ip split-horizon" >> $RIP_CONFIG
      fi
   done
   #--------------
   # RIP settings
   #--------------
   echo "router rip" >> $RIP_CONFIG
   if [ "$RipEnableWAN" = "1" ]; then
        # Enable RIP on WAN
        echo "network $WAN_IF" >> $RIP_CONFIG
   fi
   if [ "$RipEnableLAN" = "1" ]; then
        # Enable RIP on LAN
        echo "network $LAN_IF" >> $RIP_CONFIG
   fi
   #--------
   # Timers
   #--------
   echo "timers basic $RipUpdate $RipTimeout $RipGarbage" >> $RIP_CONFIG
   #---------------------
   # Route redistribution
   #---------------------
   echo "redistribute kernel" >> $RIP_CONFIG
   echo "redistribute connected" >> $RIP_CONFIG
   if [ "$RipRedistStatic" = "1" ]; then
        echo "redistribute static route-map smap" >> $RIP_CONFIG
   fi
   #--------------------------
   # Route distribution filter
   #--------------------------
   # WAN in
   echo "distribute-list DL0 in $WAN_IF" >> $RIP_CONFIG
   # WAN out
   echo "distribute-list DL1 out $WAN_IF" >> $RIP_CONFIG
   # LAN in
   echo "distribute-list DL2 in $LAN_IF" >> $RIP_CONFIG
   # LAN out
   echo "distribute-list DL3 out $LAN_IF" >> $RIP_CONFIG
   #---------------------
   # Route metric offset
   #---------------------
   if [ "$RipOffsetMetric" != "" ]; then
      if [ "$RipOffsetIn" != "0" ]; then
           echo "offset-list OffsetIn in $RipOffsetMetric" >> $RIP_CONFIG
           if [ "$RipOffsetIn" = "1" ]; then
                 OffsetInAct="permit"
                 OffsetInDefault="deny"
           else
                 OffsetInAct="deny"
                 OffsetInDefault="permit"
           fi
      else
           OffsetInAct="deny"
           OffsetInDefault="deny"
      fi
      if [ "$RipOffsetOut" != "0" ]; then
           echo "offset-list OffsetOut out $RipOffsetMetric" >> $RIP_CONFIG
           if [ "$RipOffsetOut" = "1" ]; then
                 OffsetOutAct="permit"
                 OffsetOutDefault="deny"
           else
                 OffsetOutAct="deny"
                 OffsetOutDefault="permit"
           fi
      else
           OffsetOutAct="deny"
           OffsetOutDefault="deny"
      fi
   fi
   #------------------
   # route filtering
   #------------------
   for i in 0 1 2 3 
   do
     eval DefaultAct='$'RipDRouteType${i}Act
     if [ "$DefaultAct" = "1" ]; then
          eval DRouteType${i}Act="permit"
          eval DRouteType${i}Default="deny"
     else
          eval DRouteType${i}Act="deny"
          eval DRouteType${i}Default="permit"
     fi
   done

   i=0
   while [ "$i" -lt $RipDRouteCount ]; do
     eval j='$'RipDRouteType${i}
     eval Action='$'DRouteType${j}Act
     eval IP='$'RipDRouteIP${i}
     eval Mask='$'RipDRouteMask${i}

     if [ "$IP" != "" ] && [ "$Mask" != "" ]; then
           echo "access-list DL${j} $Action ${IP}/${Mask}" >> $RIP_CONFIG
     fi
     i=$(($i+1))
   done
   for i in 0 1 2 3 
   do
     eval DefaultAct='$'DRouteType${i}Default
     echo "access-list DL${i} $DefaultAct any" >> $RIP_CONFIG
   done
   #---------------------
   # route metric offset
   #---------------------
   if [ "$RipOffsetMetric" != "" ]; then
      i=0
      while [ "$i" -lt $RipOffsetCount ]; do
        eval Dir='$'RipOffsetDir${i}
        eval IP='$'RipOffsetIP${i}
        eval Mask='$'RipOffsetMask${i}
    
        if [ "$IP" != "" ] && [ "$Mask" != "" ]; then
           if [ "$Dir" = "IN" ]; then
                echo "access-list OffsetIn $OffsetInAct ${IP}/${Mask}" >> $RIP_CONFIG
           else
                echo "access-list OffsetOut $OffsetOutAct ${IP}/${Mask}" >> $RIP_CONFIG
           fi
        fi
        i=$(($i+1))
      done
      echo "access-list OffsetIn $OffsetInDefault any" >> $RIP_CONFIG
      echo "access-list OffsetOut $OffsetOutDefault any" >> $RIP_CONFIG
   fi
   #---------------------------
   # redistribute static route
   #---------------------------
   if [ "$RipRedistStatic" = "1" ]; then
        echo "route-map smap permit 1" >> $RIP_CONFIG
        echo "match ip address SList" >> $RIP_CONFIG
        if [ "$RipSRouteMetric" != "" ] && [ "$RipSRouteMetric" != "0" ]; then
             echo "set metric $RipSRouteMetric" >> $RIP_CONFIG
        fi
        if [ "$RipSRouteAct" = "0" ]; then
             SRouteAct="permit"
             SRouteDefault="deny"
        else
             SRouteAct="deny"
             SRouteDefault="permit"
       fi
       i=0
       while [ "$i" -lt $RipSRouteCount ]; do
         eval IP='$'RipSRouteIP${i}
         eval Mask='$'RipSRouteMask${i}
    
         if [ "$IP" != "" ] && [ "$Mask" != "" ]; then
              echo "access-list SList $SRouteAct ${IP}/${Mask}" >> $RIP_CONFIG
         fi
         i=$(($i+1))
       done
       echo "access-list SList $SRouteDefault any" >> $RIP_CONFIG
   fi

   echo "RIP is up"
   ripd --config_file=${RIP_CONFIG} -d
   echo "ripd" >> /etc/watchdog.conf
fi
